/*
 * This file is part of Sponge, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.common.world.gen.builders;

import static com.google.common.base.Preconditions.checkArgument;

import org.spongepowered.api.world.gen.populator.ChorusFlower;
import org.spongepowered.api.world.gen.populator.ChorusFlower.Builder;
import org.spongepowered.common.world.gen.populators.ChorusFlowerPopulator;

public class ChorusFlowerBuilder implements ChorusFlower.Builder {

    private int exclusion = 1024;
    
    public ChorusFlowerBuilder() {
        reset();
    }

    @Override
    public Builder exclusionRadius(int radius) {
        checkArgument(radius >= 0, "Exclusion radius must be postive or zero");
        this.exclusion = radius;
        return this;
    }

    @Override
    public Builder from(ChorusFlower value) {
        return this;
    }

    @Override
    public Builder reset() {
        this.exclusion = 1024;
        return this;
    }

    @Override
    public ChorusFlower build() throws IllegalStateException {
        ChorusFlower pop = new ChorusFlowerPopulator();
        pop.setExclusionRadius(this.exclusion);
        return pop;
    }
}
